@@ -104,9 +104,9 @@ class SGraph:
 
     def get_edge_attributes(self, attr, noneval=0):
         res = []
-        for x in self.gr.edges(data=False):
+        for x in self.gr.edges(data=True):
             try:
-                res.append(self.get_edge_data(x[0], x[1], attr))
+                res.append(x[2][attr])
             except:
                 res.append(noneval)
         return np.array(res)
